#!/usr/bin/env bash

[[ ${BURR_DEPENDENCIES_LOADED:-} -eq 1 ]] && return

ensure_jq_installed() {
### If macOS
if [ ! $(which jq) ]
	then
	if [[ "$OSTYPE" == "linux-gnu" ]]; then
        sudo apt-get install jq
	elif [[ "$OSTYPE" == "darwin"* ]]; then
			# Mac OSX
			brew install jq
	else
			# Unknown.
		echo "Not sure what OS this is"
		exit 1
	fi

fi
}

# @TODO Check for readlink or greadlink
ensure_readlink_installed() {
	if [[ "$OSTYPE" == "darwin"* ]]; then
        if [ ! $(which greadlink) ]; then
			brew install coreutils
		fi
	elif [[ "$OSTYPE" == "linux-gnu" ]]; then
			echo $(which readlink)
	else
			# Unknown.
		echo "Not sure what OS this is"
		exit 1
	fi
}

ensure_git_installed() {
### If macOS
if [ ! $(which git) ]
	then
	if [[ "$OSTYPE" == "linux-gnu" ]]; then
        sudo apt-get install git
	elif [[ "$OSTYPE" == "darwin"* ]]; then
			# Mac OSX
			brew install git
	else
			# Unknown.
		echo "Not sure what OS this is"
		exit 1
	fi
fi

# Make sure the git version is recent enough
# Requires git version greater than 1.91. Versions >= 2.3.2 tested to work
echo 'working'
versioncompare $(git --version | cut -f 3 -d " ") '1.91'
git_unsupported_version=$?
if [ "$git_unsupported_version" -gt 1 ]; then
    die 'Git needs to be greater than 1.9.1. Version 2.3.2 has been tested to work'
else
    echo "Success: Git version is greater than 1.9.1"
fi

}

BURR_DEPENDENCIES_LOADED=1
